@@ -55,6 +55,7 @@ __all__ = (
     "CancelRotateSecretResponseTypeDef",
     "DeleteResourcePolicyResponseTypeDef",
     "DeleteSecretResponseTypeDef",
+    "EmptyResponseMetadataTypeDef",
     "GetRandomPasswordResponseTypeDef",
     "GetResourcePolicyResponseTypeDef",
     "GetSecretValueResponseTypeDef",
@@ -459,6 +460,13 @@ DeleteSecretResponseTypeDef = TypedDict(
     },
 )
 
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 GetRandomPasswordResponseTypeDef = TypedDict(
     "GetRandomPasswordResponseTypeDef",
     {
